.. mdinclude:: ../README.md


.. toctree::
   :name: Getting started
   :caption: Getting started
   :maxdepth: 1
   :hidden:

   getting_started/install
   getting_started/background
   getting_started/concepts
   getting_started/models

.. toctree::
   :name: Tutorials
   :caption: Tutorials
   :maxdepth: 1
   :hidden:

   tutorials/forecasting/index
   tutorials/data_manipulation/index
   tutorials/advanced_topics/index


.. toctree::
   :name: API docs
   :caption: API docs
   :maxdepth: 1
   :hidden:

   api/gluonts/gluonts

.. toctree::
   :name: Developing
   :caption: Developing
   :maxdepth: 1
   :hidden:

   community/contribute
   community/devsetup
